tiled.queries.FullText
======================

.. currentmodule:: tiled.queries

.. autoclass:: FullText

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FullText.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~FullText.case_sensitive
   
   